<?php
/*
Plugin Name: Medo OpenGraph
Plugin URI:  https://www.jmedved.com/2015/04/opengraph/
Description: Adds Facebook OpenGraph tags to posts and pages.
Version:     0.0
Author:      Josip Medved
Author URI:  http://www.jmedved.com/
License:     MIT

    Copyright (c) 2015 Josip Medved <jmedved@jmedved.com>

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to
    deal in the Software without restriction, including without limitation the
    rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
    sell copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

        o The above copyright notice and this permission notice shall be
          included in all copies or substantial portions of the Software.
        
        o THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
          EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
          MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
          IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
          CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
          TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
          SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

add_action('wp_head', 'medo_opengraph_wp_head_action');

include 'medo-opengraph-profile.php';
include 'medo-opengraph-settings.php';


function medo_opengraph_wp_head_action() {
    if (is_single() || is_page()) {
        $post = get_post();

        $title = $post->post_title;
        $type = 'article';

        foreach(get_attached_media('image') as $media) {
            $imageAttrs = wp_get_attachment_image_src($media->ID, 'full');
            $image_url =  home_url($imageAttrs[0]);
            $image_type = $media->post_mime_type;
            $image_width = $imageAttrs[1];
            $image_height = $imageAttrs[2];
            break;
        }

        $url = get_permalink($post);

        $time_created = str_replace(' ', 'T', $post->post_date_gmt) . 'Z';
        //$time_modified = str_replace(' ', 'T', $post->post_modified_gmt) . 'Z';

        $author_url = get_the_author_meta('user_url', $post->post_author);

        $author_facebook_id = get_user_meta($post->post_author, 'medo_opengraph_facebook_id', true);
        if (strlen($author_facebook_id) == 0) { $author_facebook_id = get_option('medo_opengraph_fallback_facebook_id'); }

        $author_twitter_name = get_user_meta($post->post_author, 'medo_opengraph_twitter_name', true);
        if (strlen($author_twitter_name) == 0) { $author_twitter_name = get_option('medo_opengraph_fallback_twitter_name'); }


        foreach(wp_get_post_categories($post->ID) as $category){
            $section = get_cat_name($category);
            break;
        }

        $description = $post->post_excerpt;
        if (strlen($description) == 0) {
            $description = wp_trim_words($post->post_content);
        }

    } else {

        $title = get_bloginfo('name');
        $type = 'website';
        $url = home_url();
        $description = get_bloginfo('description');

    }

    $site_name = get_bloginfo('name');
    $site_facebook_admin_id = get_option('medo_opengraph_site_facebook_admin_id');
    $site_twitter_name = get_option('medo_opengraph_site_twitter_name');


    //OpenGraph
    echo '<meta property="og:title" content="' . $title . '" />';
    echo '<meta property="og:type" content="' . $type . '" />';
    if (strlen($image_url) > 0) {
        echo '<meta property="og:image" content="' . $image_url . '" />';
        echo '<meta property="og:image:type" content="' . $image_type . '" />';
        echo '<meta property="og:image:width" content="' . $image_width . '" />';
        echo '<meta property="og:image:height" content="' . $image_height . '" />';
    }
    echo '<meta property="og:url" content="' . $url . '" />';
    if (strlen($time_created) > 0) { echo '<meta property="article:published_time" content="' . $time_created .'" />'; }
    if (strlen($time_modified) > 0) { echo '<meta property="article:modified_time"_time" content="' . $time_modified .'" />'; }
    if (strlen($author_url) > 0) { echo '<meta property="article:author" content="' . $author_url . '" />'; }

    echo '<meta property="og:description" content="' . $description . '" />';
    if (strlen($section) > 0) { echo '<meta property="article:section" content="' . $section . '" />'; }
    echo '<meta property="og:locale" content="en_US" />';
    echo '<meta property="og:site_name" content="' . $site_name .'" />';

    //Facebook
    if (strlen($author_facebook_id) > 0) { echo '<meta property="fb:profile_id" content="' . $author_facebook_id . '" />'; }
    if (strlen($site_facebook_admin_id) > 0) { echo '<meta property="fb:admins" content="' . $site_facebook_admin_id . '" />'; }

    //Twitter
    if (strlen($site_twitter_name) > 0) { echo '<meta name="twitter:site" content="@' . $site_twitter_name . '">'; }
    echo '<meta name="twitter:title" content="' . $title . '" />';
    echo '<meta name="twitter:description" content="' . $description . '" />';
    if (strlen($author_twitter_name) > 0) { echo '<meta name="twitter:creator" content="@' . $author_twitter_name . '">'; }

    //Google Plus
    echo '<meta itemprop="name" content="' . $title . '" />';
    echo '<meta itemprop="description" content="' . $description . '" />';
    if (strlen($image_url) > 0) { echo '<meta itemprop="image" content="' . $image_url . '" />'; }
}


add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'medo_opengraph_plugin_action_links_action' );

function medo_opengraph_plugin_action_links_action($links) {
    $new_links = array(
                       '<a href="' . admin_url('options-general.php?page=medo_opengraph_settings_page') . '">Settings</a>',
                       '<a href="' . admin_url('profile.php#medo_opengraph') . '">User Settings</a>',
    );
    return array_merge($links, $new_links);
}

?>
